pub unsafe fn cascade_property(
declaration: &PropertyDeclaration,
context: &mut Context<'_>,
)Expand description
Safety
declaration must be a declaration of this longhand, since its value is
read back with unchecked_value_as.
pub unsafe fn cascade_property(
declaration: &PropertyDeclaration,
context: &mut Context<'_>,
)declaration must be a declaration of this longhand, since its value is
read back with unchecked_value_as.